==> vtk6-6.3.0-9-armv7h.pkg.tar.xz: vtk/vtkExtractStructuredGridHelper.java <==
// java wrapper for vtkExtractStructuredGridHelper object
//

package vtk;
import vtk.*;

public class vtkExtractStructuredGridHelper extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int[]  GetOutputWholeExtent_2();
  public int[]  GetOutputWholeExtent()
    { return GetOutputWholeExtent_2(); }

  private native void Initialize_3(int id0[],int id1[],int id2[],boolean id3);
  public void Initialize(int id0[],int id1[],int id2[],boolean id3)
    { Initialize_3(id0,id1,id2,id3); }

  private native boolean IsValid_4();
  public boolean IsValid()
    { return IsValid_4(); }

  private native int GetSize_5(int id0);
  public int GetSize(int id0)
    { return GetSize_5(id0); }

  private native int GetMappedIndex_6(int id0,int id1);
  public int GetMappedIndex(int id0,int id1)
    { return GetMappedIndex_6(id0,id1); }

  private native int GetMappedIndexFromExtentValue_7(int id0,int id1);
  public int GetMappedIndexFromExtentValue(int id0,int id1)
    { return GetMappedIndexFromExtentValue_7(id0,id1); }

  private native int GetMappedExtentValue_8(int id0,int id1);
  public int GetMappedExtentValue(int id0,int id1)
    { return GetMappedExtentValue_8(id0,id1); }

  private native int GetMappedExtentValueFromIndex_9(int id0,int id1);
  public int GetMappedExtentValueFromIndex(int id0,int id1)
    { return GetMappedExtentValueFromIndex_9(id0,id1); }

  private native void ComputeBeginAndEnd_10(int id0[],int id1[],int id2[],int id3[]);
  public void ComputeBeginAndEnd(int id0[],int id1[],int id2[],int id3[])
    { ComputeBeginAndEnd_10(id0,id1,id2,id3); }

  private native void CopyPointsAndPointData_11(int id0[],int id1[],vtkPointData id2,vtkPoints id3,vtkPointData id4,vtkPoints id5,int id6[]);
  public void CopyPointsAndPointData(int id0[],int id1[],vtkPointData id2,vtkPoints id3,vtkPointData id4,vtkPoints id5,int id6[])
    { CopyPointsAndPointData_11(id0,id1,id2,id3,id4,id5,id6); }

  private native void CopyCellData_12(int id0[],int id1[],vtkCellData id2,vtkCellData id3,int id4[]);
  public void CopyCellData(int id0[],int id1[],vtkCellData id2,vtkCellData id3,int id4[])
    { CopyCellData_12(id0,id1,id2,id3,id4); }

  private native void GetPartitionedVOI_13(int id0[],int id1[],int id2[],boolean id3,int id4[]);
  public void GetPartitionedVOI(int id0[],int id1[],int id2[],boolean id3,int id4[])
    { GetPartitionedVOI_13(id0,id1,id2,id3,id4); }

  private native void GetPartitionedOutputExtent_14(int id0[],int id1[],int id2[],int id3[],boolean id4,int id5[]);
  public void GetPartitionedOutputExtent(int id0[],int id1[],int id2[],int id3[],boolean id4,int id5[])
    { GetPartitionedOutputExtent_14(id0,id1,id2,id3,id4,id5); }

  public vtkExtractStructuredGridHelper() { super(); }

  public vtkExtractStructuredGridHelper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkExtractStructuredGridHelper.java <==
// java wrapper for vtkExtractStructuredGridHelper object
//

package vtk;
import vtk.*;

public class vtkExtractStructuredGridHelper extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int[]  GetOutputWholeExtent_2();
  public int[]  GetOutputWholeExtent()
    { return GetOutputWholeExtent_2(); }

  private native void Initialize_3(int id0[],int id1[],int id2[],boolean id3);
  public void Initialize(int id0[],int id1[],int id2[],boolean id3)
    { Initialize_3(id0,id1,id2,id3); }

  private native boolean IsValid_4();
  public boolean IsValid()
    { return IsValid_4(); }

  private native int GetSize_5(int id0);
  public int GetSize(int id0)
    { return GetSize_5(id0); }

  private native int GetMappedIndex_6(int id0,int id1);
  public int GetMappedIndex(int id0,int id1)
    { return GetMappedIndex_6(id0,id1); }

  private native int GetMappedIndexFromExtentValue_7(int id0,int id1);
  public int GetMappedIndexFromExtentValue(int id0,int id1)
    { return GetMappedIndexFromExtentValue_7(id0,id1); }

  private native int GetMappedExtentValue_8(int id0,int id1);
  public int GetMappedExtentValue(int id0,int id1)
    { return GetMappedExtentValue_8(id0,id1); }

  private native int GetMappedExtentValueFromIndex_9(int id0,int id1);
  public int GetMappedExtentValueFromIndex(int id0,int id1)
    { return GetMappedExtentValueFromIndex_9(id0,id1); }

  private native void ComputeBeginAndEnd_10(int id0[],int id1[],int id2[],int id3[]);
  public void ComputeBeginAndEnd(int id0[],int id1[],int id2[],int id3[])
    { ComputeBeginAndEnd_10(id0,id1,id2,id3); }

  private native void CopyPointsAndPointData_11(int id0[],int id1[],vtkPointData id2,vtkPoints id3,vtkPointData id4,vtkPoints id5);
  public void CopyPointsAndPointData(int id0[],int id1[],vtkPointData id2,vtkPoints id3,vtkPointData id4,vtkPoints id5)
    { CopyPointsAndPointData_11(id0,id1,id2,id3,id4,id5); }

  private native void CopyCellData_12(int id0[],int id1[],vtkCellData id2,vtkCellData id3);
  public void CopyCellData(int id0[],int id1[],vtkCellData id2,vtkCellData id3)
    { CopyCellData_12(id0,id1,id2,id3); }

  private native void GetPartitionedVOI_13(int id0[],int id1[],int id2[],boolean id3,int id4[]);
  public void GetPartitionedVOI(int id0[],int id1[],int id2[],boolean id3,int id4[])
    { GetPartitionedVOI_13(id0,id1,id2,id3,id4); }

  private native void GetPartitionedOutputExtent_14(int id0[],int id1[],int id2[],int id3[],boolean id4,int id5[]);
  public void GetPartitionedOutputExtent(int id0[],int id1[],int id2[],int id3[],boolean id4,int id5[])
    { GetPartitionedOutputExtent_14(id0,id1,id2,id3,id4,id5); }

  public vtkExtractStructuredGridHelper() { super(); }

  public vtkExtractStructuredGridHelper(long id) { super(id); }
  public native long   VTKInit();

}
